[java-idp-integration-tests] 02/02: Workaround Chrome element not interactable exception

Tom Zeller tzeller at dragonacea.biz
Tue Aug 30 17:37:02 UTC 2022


This is an automated email from the git hooks/post-receive script.

tzeller pushed a commit to branch main
in repository java-idp-integration-tests.

View the commit online:
http://git.shibboleth.net/view/?p=java-idp-integration-tests.git;a=commit;h=84abfca0860940a195c1e472b96a3ac7e84e4f87

commit 84abfca0860940a195c1e472b96a3ac7e84e4f87
Author: Tom Zeller <tzeller at dragonacea.biz>
AuthorDate: Mon Aug 29 22:31:20 2022 -0500

    Workaround Chrome element not interactable exception
---
 .../net/shibboleth/idp/integration/tests/BaseIntegrationTest.java   | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/src/test/java/net/shibboleth/idp/integration/tests/BaseIntegrationTest.java b/src/test/java/net/shibboleth/idp/integration/tests/BaseIntegrationTest.java
index 5477f21..79758c9 100644
--- a/src/test/java/net/shibboleth/idp/integration/tests/BaseIntegrationTest.java
+++ b/src/test/java/net/shibboleth/idp/integration/tests/BaseIntegrationTest.java
@@ -80,7 +80,7 @@ import org.apache.http.impl.client.CloseableHttpClient;
 import org.apache.http.util.EntityUtils;
 import org.openqa.selenium.By;
 import org.openqa.selenium.Dimension;
-import org.openqa.selenium.ElementClickInterceptedException;
+import org.openqa.selenium.ElementNotInteractableException;
 import org.openqa.selenium.Point;
 import org.openqa.selenium.StaleElementReferenceException;
 import org.openqa.selenium.WebDriver;
@@ -2242,14 +2242,14 @@ public abstract class BaseIntegrationTest {
     /**
      * Workaround being unable to click an element because of accessibility changes.
      * 
      * Catch {@link ElementClickInterceptedException} and click via {@link Actions}.
      * 
      * @param element element to be clicked
      */
     public void clickWorkaround(final WebElement element) {
         try {
             element.click();
-        } catch (ElementClickInterceptedException e) {
+        } catch (ElementNotInteractableException e) {
             log.trace("Unable to click element {}, will try again", element);
             final Actions action = new Actions(driver);
             action.moveToElement(element).click().build().perform();
@@ -2242,14 +2242,14 @@ public abstract class BaseIntegrationTest {
      * Workaround being unable to click an element because of accessibility changes.
      * 
-     * Catch {@link ElementClickInterceptedException} and click via {@link Actions}.
+     * Catch {@link ElementNotInteractableException} and click via {@link Actions}.
      * 
      * @param element element to be clicked

-- 
To stop receiving notification emails like this one, please contact
the administrator of this repository.


More information about the commits mailing list